package Bundle::Expect;

$VERSION = '1.09';

1;

__END__

=head1 NAME

Bundle::Expect - Everything that Expect.pm needs

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Expect'>

=head1 CONTENTS

Expect

IO::Stty

IO::Tty

IO::Pty

=head1 DESCRIPTION

Everything that Expect.pm needs. What can I say more?

=head1 AUTHOR

Roland Giersig <RGiersig@users.sourceforge.net>

=cut

